@@ -22,6 +22,7 @@ public:
 
 protected:
     void changeEvent(QEvent *e);
+    void closeEvent(QCloseEvent *e);
 
 private:
     Ui::Settings *ui;
@@ -32,7 +33,6 @@ private:
 
     void getValue();
     void setValue();
-    void rejected();
 
 private slots:
     void on_pushButton_Sound_clicked();
